==> otu-5000-18.54.tar: acterna/release/smartotu/app/services/api/SMTApiSnmpListDto.php <==
<?php
// *********************************************************
// NOTICE: All rights reserved. This material contains the
// trade secrets and confidential information of Viavi Solution
// which embody substantial creative effort,
// ideas and expressions. No part of this material may be
// reproduced or transmitted in any form or by any means,
// electronic, mechanical, optical or otherwise, including
// photocopying and recording or in connection with any
// information storage or retrieval system, without
// specific written permission from Viavi Solution
// Copyright Viavi Solution 2019. All rights reserved.
// *********************************************************
namespace app\services\api;

/**
 *
 * @author sdesplat
 */
class SMTApiSnmpListDto extends SMTApiDto
{
	/**
	 * @SMTAttributeInfosAnnotation(classname='app\services\api\SMTApiSnmpDto',islist='true')
	 * @var array app\services\api\SMTApiSnmpDto
	 */
	protected $snmpManagerList = array();
	
	/**
	 * @param app\services\api\SMTApiSnmpDto
	 */
	public function addSnmpManager( SMTApiSnmpDto $snmp )
	{
		array_push( $this->snmpManagerList, $snmp);
	}
	
	/**
	 * @return array
	 */
	public function getManagers()
	{
		return $this->snmpManagerList;
	}
	
	/**
	 * Serialize as Json data the user object.<br>
	 *
	 * @return $objectProperties the object properties serialized as a Json string.
	 */
	function getJsonData()
	{
		$objectProperties = get_object_vars($this);
		$this->serializeObjectAsJsonData( $objectProperties, FALSE);
		return $objectProperties;
	}
	
	/**
	 * Returns Dto class name.
	 *
	 * @return string the dtop class name
	 */
	function getDtoClassName()
	{
		return get_class();
	}
	
	/**
	 * Create the Dto from a Json Dto in an array
	 *
	 * @param array $json_array json data in an array
	 *
	 * @return \app\services\api\SMTApiLinkListDto
	 */
	static function getInstance( array &$json_array )
	{
		return self::forge( get_class(), $json_array );
	}

}

==> otu-5000-24.10020.tar: acterna/release/smartotu/app/services/api/SMTApiSnmpListDto.php <==
<?php
// *********************************************************
// NOTICE: All rights reserved. This material contains the
// trade secrets and confidential information of Viavi Solution
// which embody substantial creative effort,
// ideas and expressions. No part of this material may be
// reproduced or transmitted in any form or by any means,
// electronic, mechanical, optical or otherwise, including
// photocopying and recording or in connection with any
// information storage or retrieval system, without
// specific written permission from Viavi Solution
// Copyright Viavi Solution 2019. All rights reserved.
// *********************************************************
namespace app\services\api;

/**
 *
 * @author sdesplat
 */
class SMTApiSnmpListDto extends SMTApiDto
{
	/**
	 * @SMTAttributeInfosAnnotation(classname='app\services\api\SMTApiSnmpDto',islist='true')
	 * @var array app\services\api\SMTApiSnmpDto
	 */
	protected $snmpManagerList = array();
	
	/**
	 * @param app\services\api\SMTApiSnmpDto
	 */
	public function addSnmpManager( SMTApiSnmpDto $snmp )
	{
		array_push( $this->snmpManagerList, $snmp);
	}
	
	/**
	 * @return array
	 */
	public function getManagers()
	{
		return $this->snmpManagerList;
	}
	
	public function stripHtmlTags()
	{
		foreach ( $this->snmpManagerList as $snmpDto )
		{
			$snmpDto->stripHtmlTags();
		}
	}
	
	/**
	 * Serialize as Json data the user object.<br>
	 *
	 * @return $objectProperties the object properties serialized as a Json string.
	 */
	function getJsonData()
	{
		$objectProperties = get_object_vars($this);
		$this->serializeObjectAsJsonData( $objectProperties, FALSE);
		return $objectProperties;
	}
	
	/**
	 * Returns Dto class name.
	 *
	 * @return string the dtop class name
	 */
	function getDtoClassName()
	{
		return get_class();
	}
	
	/**
	 * Create the Dto from a Json Dto in an array
	 *
	 * @param array $json_array json data in an array
	 *
	 * @return \app\services\api\SMTApiLinkListDto
	 */
	static function getInstance( array &$json_array )
	{
		$instance = self::forge( get_class(), $json_array );
		$instance->stripHtmlTags();
		return $instance;
	}

}
